@@ -10,7 +10,7 @@
   id toList;
   id <Canvas> canvas;
   id <NodeItem> nodeItem;
-  id nodeType;
+  id <Symbol> nodeType;
   const char *label;
   id uRandPosition;
 }
@@ -35,5 +35,6 @@
 - hideNode;
 - (void)drop;
 - setNodeLabel: (const char *)aLabel;
+- (const char *) getNodeLabel;
 
 @end
